@@ -3,6 +3,7 @@ package Deep::Hash::Exists;
 use strict;
 use warnings;
 use utf8;
+use Scalar::Util;
 
 use base qw( Exporter );
 
@@ -13,13 +14,13 @@ our @EXPORT_OK = qw(
         some_keys 
 );
 our %EXPORT_TAGS = ( all => [ @EXPORT, @EXPORT_OK ] );
-our $VERSION = '0.2';
+our $VERSION = '0.21';
 
 sub key_exists($$) {
     my $hash_ref = shift;
     my $array_ref = shift;
     
-    return 0 if ref $hash_ref ne 'HASH';
+    return 0 if Scalar::Util::reftype $hash_ref ne 'HASH';
     
     my $key = shift @$array_ref;
     
@@ -143,13 +144,18 @@ Output:
  #        };
 
 
+=head1 METHODS
+
+The first argument in methods I<key_exists>, I<every_keys> and I<some_keys> can be a hash reference and a blessed hash.
+
+
 =head2 key_exists($$)
 
 B<key_exists>( I<$hash_ref, $array_ref_keys> ) - Verify existence of keys hash.
 
 B<Return>:
 
-    If exist keys of hash then return 1, otherwise - 0.
+If exist keys of hash then return 1, otherwise - 0.
 
 B<Example>:
  
@@ -185,7 +191,7 @@ B<every_keys>( I<$hash_ref, $list_array_ref> ) - Verify list of hash keys for ex
 
 B<Return>:
 
-    If exist all keys of hash of the submitted list then return 1, otherwise - 0.
+If exist all keys of hash of the submitted list then return 1, otherwise - 0.
 
 B<Example>:
 
@@ -212,7 +218,7 @@ B<some_keys>( I<$hash_ref, $list_array_ref> ) - Verify list of hash keys for exi
 
 B<Return>:
 
-    If exist at least one key of hash of the submitted list then return 1, otherwise - 0.
+If exist at least one key of hash of the submitted list then return 1, otherwise - 0.
 
 B<Example>:
 
